/*
 * Copyright (C) 2015 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef AAPT_XMLIDCOLLECTOR_H
#define AAPT_XMLIDCOLLECTOR_H

#include "process/IResourceTableConsumer.h"
#include "xml/XmlDom.h"

namespace aapt {

struct XmlIdCollector : public IXmlResourceConsumer {
  bool Consume(IAaptContext* context, xml::XmlResource* xml_res) override;
};

}  // namespace aapt

#endif /* AAPT_XMLIDCOLLECTOR_H */
